==> lsb-build-base2_2.1.1.orig.tar.gz: lsb-build-base2-2.1.1.orig/build_env/stub_libs/IA32/libpthread.c <==
void _pthread_cleanup_pop() {} ;
void _pthread_cleanup_push() {} ;
void pread() {} ;
void pread64() {} ;
void pthread_attr_destroy() {} ;
void pthread_attr_getdetachstate() {} ;
void pthread_attr_getguardsize() {} ;
void pthread_attr_getschedparam() {} ;
void pthread_attr_getstack() {} ;
void pthread_attr_getstackaddr() {} ;
void pthread_attr_getstacksize() {} ;
void pthread_attr_init() {} ;
void pthread_attr_setdetachstate() {} ;
void pthread_attr_setguardsize() {} ;
void pthread_attr_setschedparam() {} ;
void pthread_attr_setstack() {} ;
void pthread_attr_setstackaddr() {} ;
void pthread_attr_setstacksize() {} ;
void pthread_cancel() {} ;
void pthread_cond_broadcast() {} ;
void pthread_cond_destroy() {} ;
void pthread_cond_init() {} ;
void pthread_cond_signal() {} ;
void pthread_cond_timedwait() {} ;
void pthread_cond_wait() {} ;
void pthread_condattr_destroy() {} ;
void pthread_condattr_getpshared() {} ;
void pthread_condattr_init() {} ;
void pthread_condattr_setpshared() {} ;
void pthread_create() {} ;
void pthread_detach() {} ;
void pthread_equal() {} ;
void pthread_exit() {} ;
void pthread_getconcurrency() {} ;
void pthread_getspecific() {} ;
void pthread_join() {} ;
void pthread_key_create() {} ;
void pthread_key_delete() {} ;
void pthread_kill() {} ;
void pthread_mutex_destroy() {} ;
void pthread_mutex_init() {} ;
void pthread_mutex_lock() {} ;
void pthread_mutex_trylock() {} ;
void pthread_mutex_unlock() {} ;
void pthread_mutexattr_destroy() {} ;
void pthread_mutexattr_getpshared() {} ;
void pthread_mutexattr_gettype() {} ;
void pthread_mutexattr_init() {} ;
void pthread_mutexattr_setpshared() {} ;
void pthread_mutexattr_settype() {} ;
void pthread_once() {} ;
void pthread_rwlock_destroy() {} ;
void pthread_rwlock_init() {} ;
void pthread_rwlock_rdlock() {} ;
void pthread_rwlock_timedrdlock() {} ;
void pthread_rwlock_timedwrlock() {} ;
void pthread_rwlock_tryrdlock() {} ;
void pthread_rwlock_trywrlock() {} ;
void pthread_rwlock_unlock() {} ;
void pthread_rwlock_wrlock() {} ;
void pthread_rwlockattr_destroy() {} ;
void pthread_rwlockattr_getpshared() {} ;
void pthread_rwlockattr_init() {} ;
void pthread_rwlockattr_setpshared() {} ;
void pthread_self() {} ;
void pthread_setcancelstate() {} ;
void pthread_setcanceltype() {} ;
void pthread_setconcurrency() {} ;
void pthread_setspecific() {} ;
void pthread_sigmask() {} ;
void pthread_testcancel() {} ;
void pwrite() {} ;
void pwrite64() {} ;
void sem_close() {} ;
void sem_destroy() {} ;
void sem_getvalue() {} ;
void sem_init() {} ;
void sem_open() {} ;
void sem_post() {} ;
void sem_timedwait() {} ;
void sem_trywait() {} ;
void sem_unlink() {} ;
void sem_wait() {} ;

==> lsb-build-base3_3.2.2~pre1.orig.tar.gz: lsb-build-base-3.2.2/build_env/stub_libs/IA32/libpthread.c <==
void _pthread_cleanup_pop() {} ;
void _pthread_cleanup_push() {} ;
void lseek64() {} ;
void open64() {} ;
void pread() {} ;
void pread64() {} ;
void pthread_attr_destroy() {} ;
void pthread_attr_getdetachstate() {} ;
void pthread_attr_getguardsize() {} ;
void pthread_attr_getinheritsched() {} ;
void pthread_attr_getschedparam() {} ;
void pthread_attr_getschedpolicy() {} ;
void pthread_attr_getscope() {} ;
void pthread_attr_getstack() {} ;
void pthread_attr_getstackaddr() {} ;
void pthread_attr_getstacksize() {} ;
void pthread_attr_init() {} ;
void pthread_attr_setdetachstate() {} ;
void pthread_attr_setguardsize() {} ;
void pthread_attr_setinheritsched() {} ;
void pthread_attr_setschedparam() {} ;
void pthread_attr_setschedpolicy() {} ;
void pthread_attr_setscope() {} ;
void pthread_attr_setstack() {} ;
void pthread_attr_setstackaddr() {} ;
void pthread_attr_setstacksize() {} ;
void pthread_barrier_destroy() {} ;
void pthread_barrier_init() {} ;
void pthread_barrier_wait() {} ;
void pthread_barrierattr_destroy() {} ;
void pthread_barrierattr_getpshared() {} ;
void pthread_barrierattr_init() {} ;
void pthread_barrierattr_setpshared() {} ;
void pthread_cancel() {} ;
void pthread_cond_broadcast() {} ;
void pthread_cond_destroy() {} ;
void pthread_cond_init() {} ;
void pthread_cond_signal() {} ;
void pthread_cond_timedwait() {} ;
void pthread_cond_wait() {} ;
void pthread_condattr_destroy() {} ;
void pthread_condattr_getpshared() {} ;
void pthread_condattr_init() {} ;
void pthread_condattr_setpshared() {} ;
void pthread_create() {} ;
void pthread_detach() {} ;
void pthread_equal() {} ;
void pthread_exit() {} ;
void pthread_getconcurrency() {} ;
void pthread_getcpuclockid() {} ;
void pthread_getschedparam() {} ;
void pthread_getspecific() {} ;
void pthread_join() {} ;
void pthread_key_create() {} ;
void pthread_key_delete() {} ;
void pthread_kill() {} ;
void pthread_mutex_destroy() {} ;
void pthread_mutex_init() {} ;
void pthread_mutex_lock() {} ;
void pthread_mutex_timedlock() {} ;
void pthread_mutex_trylock() {} ;
void pthread_mutex_unlock() {} ;
void pthread_mutexattr_destroy() {} ;
void pthread_mutexattr_getpshared() {} ;
void pthread_mutexattr_gettype() {} ;
void pthread_mutexattr_init() {} ;
void pthread_mutexattr_setpshared() {} ;
void pthread_mutexattr_settype() {} ;
void pthread_once() {} ;
void pthread_rwlock_destroy() {} ;
void pthread_rwlock_init() {} ;
void pthread_rwlock_rdlock() {} ;
void pthread_rwlock_timedrdlock() {} ;
void pthread_rwlock_timedwrlock() {} ;
void pthread_rwlock_tryrdlock() {} ;
void pthread_rwlock_trywrlock() {} ;
void pthread_rwlock_unlock() {} ;
void pthread_rwlock_wrlock() {} ;
void pthread_rwlockattr_destroy() {} ;
void pthread_rwlockattr_getpshared() {} ;
void pthread_rwlockattr_init() {} ;
void pthread_rwlockattr_setpshared() {} ;
void pthread_self() {} ;
void pthread_setcancelstate() {} ;
void pthread_setcanceltype() {} ;
void pthread_setconcurrency() {} ;
void pthread_setschedparam() {} ;
void pthread_setschedprio() {} ;
void pthread_setspecific() {} ;
void pthread_sigmask() {} ;
void pthread_spin_destroy() {} ;
void pthread_spin_init() {} ;
void pthread_spin_lock() {} ;
void pthread_spin_trylock() {} ;
void pthread_spin_unlock() {} ;
void pthread_testcancel() {} ;
void pwrite() {} ;
void pwrite64() {} ;
void sem_close() {} ;
void sem_destroy() {} ;
void sem_getvalue() {} ;
void sem_init() {} ;
void sem_open() {} ;
void sem_post() {} ;
void sem_timedwait() {} ;
void sem_trywait() {} ;
void sem_unlink() {} ;
void sem_wait() {} ;
